pub struct QuestTemplate {Show 15 fields
pub id: QuestId,
pub title: I18nString,
pub description: I18nString,
pub progress_script: String,
pub progress_target: i64,
pub quest_group_type: QuestGroupType,
pub bundle_id: Option<BundleId>,
pub progression_points: u64,
pub starting: bool,
pub next_quest_ids: Vec<QuestId>,
pub events_subscribe: Vec<String>,
pub additional_quests_script: Option<String>,
pub progress_if_inactive: bool,
pub screen_reference: Option<ScreenType>,
pub code: Option<String>,
}Fields
id: QuestIdtitle: I18nStringdescription: I18nStringprogress_script: Stringprogress_target: i64quest_group_type: QuestGroupTypebundle_id: Option<BundleId>progression_points: u64starting: boolnext_quest_ids: Vec<QuestId>events_subscribe: Vec<String>additional_quests_script: Option<String>progress_if_inactive: boolscreen_reference: Option<ScreenType>code: Option<String>Trait Implementations
Sourceimpl Clone for QuestTemplate
impl Clone for QuestTemplate
Sourcefn clone(&self) -> QuestTemplate
fn clone(&self) -> QuestTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for QuestTemplate
impl CustomType for QuestTemplate
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for QuestTemplate
impl Debug for QuestTemplate
Sourceimpl<'de> Deserialize<'de> for QuestTemplate
impl<'de> Deserialize<'de> for QuestTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for QuestTemplate
impl Hash for QuestTemplate
Sourceimpl JsonSchema for QuestTemplate
impl JsonSchema for QuestTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QuestTemplate
impl PartialEq for QuestTemplate
Sourceimpl Serialize for QuestTemplate
impl Serialize for QuestTemplate
Sourceimpl Tsify for QuestTemplate
impl Tsify for QuestTemplate
const DECL: &'static str = "export interface QuestTemplate {\n id: QuestId;\n title: I18nString;\n description: I18nString;\n progress_script: string;\n progress_target: number;\n quest_group_type: QuestGroupType;\n bundle_id: BundleId | null;\n progression_points: number;\n starting: boolean;\n next_quest_ids: QuestId[];\n events_subscribe: string[];\n additional_quests_script: string | null;\n progress_if_inactive: boolean;\n screen_reference: ScreenType | null;\n code: string | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for QuestTemplate
impl StructuralPartialEq for QuestTemplate