pub struct QuestsProgressTrack {
pub current_points: u64,
pub period_end_date: DateTime<Utc>,
pub rewards: Vec<QuestsTrackReward>,
}Fields
current_points: u64period_end_date: DateTime<Utc>rewards: Vec<QuestsTrackReward>Trait Implementations
Sourceimpl Clone for QuestsProgressTrack
impl Clone for QuestsProgressTrack
Sourcefn clone(&self) -> QuestsProgressTrack
fn clone(&self) -> QuestsProgressTrack
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for QuestsProgressTrack
impl CustomType for QuestsProgressTrack
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for QuestsProgressTrack
impl Debug for QuestsProgressTrack
Sourceimpl Default for QuestsProgressTrack
impl Default for QuestsProgressTrack
Sourcefn default() -> QuestsProgressTrack
fn default() -> QuestsProgressTrack
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for QuestsProgressTrack
impl<'de> Deserialize<'de> for QuestsProgressTrack
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QuestsProgressTrack
impl JsonSchema for QuestsProgressTrack
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QuestsProgressTrack
impl PartialEq for QuestsProgressTrack
Sourceimpl Serialize for QuestsProgressTrack
impl Serialize for QuestsProgressTrack
Sourceimpl Tsify for QuestsProgressTrack
impl Tsify for QuestsProgressTrack
const DECL: &'static str = "export interface QuestsProgressTrack {\n current_points: number;\n period_end_date: DateTime<Utc>;\n rewards: QuestsTrackReward[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for QuestsProgressTrack
impl StructuralPartialEq for QuestsProgressTrack