pub struct QuestsProgressionGroup {
pub progress_track: QuestsProgressTrack,
pub quests: Vec<QuestInstance>,
}Fields
progress_track: QuestsProgressTrackquests: Vec<QuestInstance>Trait Implementations
Sourceimpl Clone for QuestsProgressionGroup
impl Clone for QuestsProgressionGroup
Sourcefn clone(&self) -> QuestsProgressionGroup
fn clone(&self) -> QuestsProgressionGroup
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for QuestsProgressionGroup
impl CustomType for QuestsProgressionGroup
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for QuestsProgressionGroup
impl Debug for QuestsProgressionGroup
Sourceimpl Default for QuestsProgressionGroup
impl Default for QuestsProgressionGroup
Sourcefn default() -> QuestsProgressionGroup
fn default() -> QuestsProgressionGroup
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for QuestsProgressionGroup
impl<'de> Deserialize<'de> for QuestsProgressionGroup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QuestsProgressionGroup
impl JsonSchema for QuestsProgressionGroup
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QuestsProgressionGroup
impl PartialEq for QuestsProgressionGroup
Sourceimpl Serialize for QuestsProgressionGroup
impl Serialize for QuestsProgressionGroup
Sourceimpl Tsify for QuestsProgressionGroup
impl Tsify for QuestsProgressionGroup
const DECL: &'static str = "export interface QuestsProgressionGroup {\n progress_track: QuestsProgressTrack;\n quests: QuestInstance[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for QuestsProgressionGroup
impl StructuralPartialEq for QuestsProgressionGroup