pub struct QuestsProgressionPointSettings {
pub points: u64,
pub reward_script: String,
}Fields
points: u64reward_script: StringTrait Implementations
Sourceimpl Clone for QuestsProgressionPointSettings
impl Clone for QuestsProgressionPointSettings
Sourcefn clone(&self) -> QuestsProgressionPointSettings
fn clone(&self) -> QuestsProgressionPointSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for QuestsProgressionPointSettings
impl<'de> Deserialize<'de> for QuestsProgressionPointSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QuestsProgressionPointSettings
impl JsonSchema for QuestsProgressionPointSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QuestsProgressionPointSettings
impl PartialEq for QuestsProgressionPointSettings
Sourcefn eq(&self, other: &QuestsProgressionPointSettings) -> bool
fn eq(&self, other: &QuestsProgressionPointSettings) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Tsify for QuestsProgressionPointSettings
impl Tsify for QuestsProgressionPointSettings
const DECL: &'static str = "export interface QuestsProgressionPointSettings {\n points: number;\n reward_script: string;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for QuestsProgressionPointSettings
impl StructuralPartialEq for QuestsProgressionPointSettings