pub struct QuestsProgressionSettings {
pub daily: Vec<QuestsProgressionPointSettings>,
pub weekly: Vec<QuestsProgressionPointSettings>,
pub achievement: Vec<QuestsProgressionPointSettings>,
}Fields
daily: Vec<QuestsProgressionPointSettings>weekly: Vec<QuestsProgressionPointSettings>achievement: Vec<QuestsProgressionPointSettings>Trait Implementations
Sourceimpl Clone for QuestsProgressionSettings
impl Clone for QuestsProgressionSettings
Sourcefn clone(&self) -> QuestsProgressionSettings
fn clone(&self) -> QuestsProgressionSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QuestsProgressionSettings
impl Debug for QuestsProgressionSettings
Sourceimpl<'de> Deserialize<'de> for QuestsProgressionSettings
impl<'de> Deserialize<'de> for QuestsProgressionSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QuestsProgressionSettings
impl JsonSchema for QuestsProgressionSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for QuestsProgressionSettings
impl Tsify for QuestsProgressionSettings
const DECL: &'static str = "export interface QuestsProgressionSettings {\n daily: QuestsProgressionPointSettings[];\n weekly: QuestsProgressionPointSettings[];\n achievement: QuestsProgressionPointSettings[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for QuestsProgressionSettings
impl StructuralPartialEq for QuestsProgressionSettings